@@ -6,7 +6,7 @@ struct dirent *q_vdb_get_next_dir(DIR *dir)
 {
 	/* search for a category directory */
 	struct dirent *ret;
-	int len, i;
+	size_t i;
 
 next_entry:
 	ret = readdir(dir);
@@ -18,8 +18,7 @@ next_entry:
 	if (ret->d_name[0] == '.' || ret->d_name[0] == '-')
 		goto next_entry;
 
-	len = strlen(ret->d_name);
-	for (i = 0; i < len; i++) {
+	for (i = 0; ret->d_name[i]; ++i) {
 		if (!isalnum(ret->d_name[i])) { /* [A-Za-z0-9+_.-] */
 			switch (ret->d_name[i]) {
 				case '+':
